import notebooks.testTimeAugmentation
import sys
try:
    from PyQt5.QtGui import *
    from PyQt5.QtCore import *
    from PyQt5.QtWidgets import *
except ImportError:
    # needed for py3+qt4
    # Ref:
    # http://pyqt.sourceforge.net/Docs/PyQt4/incompatible_apis.html
    # http://stackoverflow.com/questions/21217399/pyqt4-qtcore-qvariant-object-instead-of-a-string
    if sys.version_info.major >= 3:
        import sip
        sip.setapi('QVariant', 2)
    #from PyQt4.QtGui import *
    #from PyQt4.QtCore import *

from libs.utils import *
from libs.ustr import ustr
from os import listdir
import glob

listaModels=[]
def selectTecniques(self, avg, bila,blur,chanhsv,chanlab,crop,drop,elas,histo,vflip,hflip,hvflip,gamma,blurGa,gaunoise,
                    invert,median, none, raiseB, raiseGreen, raiseHue, raisered, raisesatu, raiseval,resize, rot10,
                    rot90, rot180, rot270, saltpe, sharpen, sift, shear, trans):
    listaModels=[]
    if avg == True:
        listaModels.append("avgBlur")
    if bila == True:
        listaModels.append("bilaBlur")
    if blur == True:
        listaModels.append("blur")
    if chanhsv == True:
        listaModels.append("chanHsv")
    if chanlab == True:
        listaModels.append("chanLab")
    if crop == True:
        listaModels.append("crop")
    if drop == True:
        listaModels.append("dropOut")
    if elas == True:
        listaModels.append("elastic")
    if histo == True:
        listaModels.append("histo")
    if vflip == True:
        listaModels.append("vflip")
    if hflip == True:
        listaModels.append("hflip")
    if hvflip == True:
        listaModels.append("hvflip")
    if gamma == True:
        listaModels.append("gamma")
    if blurGa == True:
        listaModels.append("blurGau")
    if gaunoise == True:
        listaModels.append("avgNoise")
    if invert == True:
        listaModels.append("invert")
    if median == True:
        listaModels.append("medianblur")
    if none == True:
        listaModels.append("none")
    if raiseB == True:
        listaModels.append("raiseBlue")
    if raiseGreen == True:
        listaModels.append("raiseGreen")
    if raiseHue == True:
        listaModels.append("raiseHue")
    if raisered == True:
        listaModels.append("raiseRed")
    if raisesatu == True:
        listaModels.append("raiseSatu")
    if raiseval == True:
        listaModels.append("raiseValue")
    if resize == True:
        listaModels.append("resize")
    if rot10 == True:
        listaModels.append("rotation10")
    if rot90 == True:
        listaModels.append("rotation90")
    if rot180 == True:
        listaModels.append("rotation180")
    if rot270 == True:
        listaModels.append("rotation270")
    if saltpe == True:
        listaModels.append("saltPeper")
    if sharpen == True:
        listaModels.append("sharpen")
    if sift == True:
        listaModels.append("shiftChannel")
    if shear == True:
        listaModels.append("shearing")
    if trans == True:
        listaModels.append("translation")
    return listaModels


def selectModel(self,rb_1):
    model = None
    #pesos = False
    #comprobamos cual es la red que se ha elegido
    targetDirPath = ustr(QFileDialog.getExistingDirectory(self, 'Select the directory of the weights', '',
                                                          QFileDialog.ShowDirsOnly ))
    if rb_1 == True:
        #se ha elegido la red YOLO por lo que necesitamos tres ficheros de configuracion
        listFich = listdir(targetDirPath)
        if len(listFich) == 3:
            fichWeights = glob.glob(targetDirPath+'/*.weights', recursive=False)
            fichNames = glob.glob(targetDirPath+'/*.names', recursive=False)
            fichCfg = glob.glob(targetDirPath+'/*.cfg', recursive=False)
            if (len(fichWeights)==1 and len(fichNames)==1 and len(fichCfg)==1 ):
                model = yoloDarknet = notebooks.testTimeAugmentation.DarknetYoloPred(fichWeights[0], fichNames[0],fichCfg[0])
                #pesos = True
            else:
                QMessageBox.about(self, "Error", 'The files are not correct. You need this files: .weight, .names and .cfg.')
            #path = os.path.dirname(ustr(self.filePath)) if self.filePath else '.'
            #yoloDarknet.predict(path,path)

        else:
            QMessageBox.about(self, "Error", 'This directory does not contain three files.')

    return model

def selectOption(aff, con, una):
    if aff == True:
        option = 'affirmative'
    elif con == True:
        option = 'consensus'
    elif una == True:
        option = 'unanimous'
    return option



# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'notebookmenu.ui'
#
# Created by: PyQt5 UI code generator 5.10.1
#
# WARNING! All changes made in this file will be lost!

from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_Dialog(object):
    genera = False
    def setupUi(self,Ui_Dialog):
        Ui_Dialog.setObjectName("Dialog")
        Ui_Dialog.resize(1001, 607)
        self.dialog = Ui_Dialog
        self.buttonBox = QtWidgets.QDialogButtonBox(Ui_Dialog)
        self.buttonBox.setGeometry(QtCore.QRect(800, 560, 191, 32))
        self.buttonBox.setOrientation(QtCore.Qt.Horizontal)
        self.buttonBox.setStandardButtons(QtWidgets.QDialogButtonBox.Cancel | QtWidgets.QDialogButtonBox.Ok)
        self.buttonBox.setObjectName("buttonBox")
        self.checkBox_avg = QtWidgets.QCheckBox(Ui_Dialog)
        self.checkBox_avg.setGeometry(QtCore.QRect(20, 70, 141, 23))
        self.checkBox_avg.setObjectName("checkBox_avg")
        self.label = QtWidgets.QLabel(Ui_Dialog)
        self.label.setGeometry(QtCore.QRect(30, 20, 181, 17))
        self.label.setObjectName("label")
        self.checkBox_biBlu = QtWidgets.QCheckBox(Ui_Dialog)
        self.checkBox_biBlu.setGeometry(QtCore.QRect(20, 120, 141, 23))
        self.checkBox_biBlu.setObjectName("checkBox_biBlu")
        self.checkBox_crop = QtWidgets.QCheckBox(Ui_Dialog)
        self.checkBox_crop.setGeometry(QtCore.QRect(20, 320, 141, 23))
        self.checkBox_crop.setObjectName("checkBox_crop")
        self.checkBox_blu = QtWidgets.QCheckBox(Ui_Dialog)
        self.checkBox_blu.setGeometry(QtCore.QRect(20, 170, 141, 23))
        self.checkBox_blu.setObjectName("checkBox_blu")
        self.checkBox_blur2 = QtWidgets.QCheckBox(Ui_Dialog)
        self.checkBox_blur2.setGeometry(QtCore.QRect(20, 270, 141, 23))
        self.checkBox_blur2.setObjectName("checkBox_blur2")
        self.checkBox_hsv = QtWidgets.QCheckBox(Ui_Dialog)
        self.checkBox_hsv.setGeometry(QtCore.QRect(20, 220, 171, 23))
        self.checkBox_hsv.setObjectName("checkBox_hsv")
        self.checkBox_his = QtWidgets.QCheckBox(Ui_Dialog)
        self.checkBox_his.setGeometry(QtCore.QRect(230, 120, 181, 23))
        self.checkBox_his.setObjectName("checkBox_his")
        self.checkBox_gam = QtWidgets.QCheckBox(Ui_Dialog)
        self.checkBox_gam.setGeometry(QtCore.QRect(230, 320, 151, 23))
        self.checkBox_gam.setObjectName("checkBox_gam")
        self.checkBox_ver = QtWidgets.QCheckBox(Ui_Dialog)
        self.checkBox_ver.setGeometry(QtCore.QRect(230, 170, 141, 23))
        self.checkBox_ver.setObjectName("checkBox_ver")
        self.checkBox_flip = QtWidgets.QCheckBox(Ui_Dialog)
        self.checkBox_flip.setGeometry(QtCore.QRect(230, 220, 141, 23))
        self.checkBox_flip.setObjectName("checkBox_flip")
        self.checkBox_hvflip = QtWidgets.QCheckBox(Ui_Dialog)
        self.checkBox_hvflip.setGeometry(QtCore.QRect(230, 270, 201, 23))
        self.checkBox_hvflip.setObjectName("checkBox_hvflip")
        self.checkBox_elas = QtWidgets.QCheckBox(Ui_Dialog)
        self.checkBox_elas.setGeometry(QtCore.QRect(230, 70, 181, 23))
        self.checkBox_elas.setObjectName("checkBox_elas")
        self.checkBox_inv = QtWidgets.QCheckBox(Ui_Dialog)
        self.checkBox_inv.setGeometry(QtCore.QRect(440, 120, 141, 23))
        self.checkBox_inv.setObjectName("checkBox_inv")
        self.checkBox_green = QtWidgets.QCheckBox(Ui_Dialog)
        self.checkBox_green.setGeometry(QtCore.QRect(440, 320, 161, 23))
        self.checkBox_green.setObjectName("checkBox_green")
        self.checkBox_med = QtWidgets.QCheckBox(Ui_Dialog)
        self.checkBox_med.setGeometry(QtCore.QRect(440, 170, 141, 23))
        self.checkBox_med.setObjectName("checkBox_med")
        self.checkBox_none = QtWidgets.QCheckBox(Ui_Dialog)
        self.checkBox_none.setGeometry(QtCore.QRect(440, 220, 141, 23))
        self.checkBox_none.setObjectName("checkBox_none")
        self.checkBox_blue = QtWidgets.QCheckBox(Ui_Dialog)
        self.checkBox_blue.setGeometry(QtCore.QRect(440, 270, 161, 23))
        self.checkBox_blue.setObjectName("checkBox_blue")
        self.checkBox_add = QtWidgets.QCheckBox(Ui_Dialog)
        self.checkBox_add.setGeometry(QtCore.QRect(440, 70, 181, 23))
        self.checkBox_add.setObjectName("checkBox_add")
        self.checkBox_sat = QtWidgets.QCheckBox(Ui_Dialog)
        self.checkBox_sat.setGeometry(QtCore.QRect(650, 120, 141, 23))
        self.checkBox_sat.setObjectName("checkBox_sat")
        self.checkBox_r90 = QtWidgets.QCheckBox(Ui_Dialog)
        self.checkBox_r90.setGeometry(QtCore.QRect(650, 320, 141, 23))
        self.checkBox_r90.setObjectName("checkBox_r90")
        self.checkBox_val = QtWidgets.QCheckBox(Ui_Dialog)
        self.checkBox_val.setGeometry(QtCore.QRect(650, 170, 141, 23))
        self.checkBox_val.setObjectName("checkBox_val")
        self.checkBox_resi = QtWidgets.QCheckBox(Ui_Dialog)
        self.checkBox_resi.setGeometry(QtCore.QRect(650, 220, 141, 23))
        self.checkBox_resi.setObjectName("checkBox_resi")
        self.checkBox_r10 = QtWidgets.QCheckBox(Ui_Dialog)
        self.checkBox_r10.setGeometry(QtCore.QRect(650, 270, 141, 23))
        self.checkBox_r10.setObjectName("checkBox_r10")
        self.checkBox_red = QtWidgets.QCheckBox(Ui_Dialog)
        self.checkBox_red.setGeometry(QtCore.QRect(650, 70, 141, 23))
        self.checkBox_red.setObjectName("checkBox_red")
        self.checkBox_drop = QtWidgets.QCheckBox(Ui_Dialog)
        self.checkBox_drop.setGeometry(QtCore.QRect(20, 370, 141, 23))
        self.checkBox_drop.setObjectName("checkBox_drop")
        self.checkBox_gau = QtWidgets.QCheckBox(Ui_Dialog)
        self.checkBox_gau.setGeometry(QtCore.QRect(230, 370, 141, 23))
        self.checkBox_gau.setObjectName("checkBox_gau")
        self.checkBox_hue = QtWidgets.QCheckBox(Ui_Dialog)
        self.checkBox_hue.setGeometry(QtCore.QRect(440, 370, 141, 23))
        self.checkBox_hue.setObjectName("checkBox_hue")
        self.checkBox_r180 = QtWidgets.QCheckBox(Ui_Dialog)
        self.checkBox_r180.setGeometry(QtCore.QRect(650, 370, 141, 23))
        self.checkBox_r180.setObjectName("checkBox_r180")
        self.checkBox_trans = QtWidgets.QCheckBox(Ui_Dialog)
        self.checkBox_trans.setGeometry(QtCore.QRect(860, 320, 141, 23))
        self.checkBox_trans.setObjectName("checkBox_trans")
        self.checkBox_r270 = QtWidgets.QCheckBox(Ui_Dialog)
        self.checkBox_r270.setGeometry(QtCore.QRect(860, 70, 141, 23))
        self.checkBox_r270.setObjectName("checkBox_r270")
        self.checkBox_shift = QtWidgets.QCheckBox(Ui_Dialog)
        self.checkBox_shift.setGeometry(QtCore.QRect(860, 220, 141, 23))
        self.checkBox_shift.setObjectName("checkBox_shift")
        self.checkBox_salt = QtWidgets.QCheckBox(Ui_Dialog)
        self.checkBox_salt.setGeometry(QtCore.QRect(860, 120, 141, 23))
        self.checkBox_salt.setObjectName("checkBox_salt")
        self.checkBox_shear = QtWidgets.QCheckBox(Ui_Dialog)
        self.checkBox_shear.setGeometry(QtCore.QRect(860, 270, 141, 23))
        self.checkBox_shear.setObjectName("checkBox_shear")
        self.checkBox_shar = QtWidgets.QCheckBox(Ui_Dialog)
        self.checkBox_shar.setGeometry(QtCore.QRect(860, 170, 141, 23))
        self.checkBox_shar.setObjectName("checkBox_shar")
        self.line = QtWidgets.QFrame(Ui_Dialog)
        self.line.setGeometry(QtCore.QRect(20, 400, 971, 20))
        self.line.setFrameShape(QtWidgets.QFrame.HLine)
        self.line.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line.setObjectName("line")
        self.radioButton_aff = QtWidgets.QRadioButton(Ui_Dialog)
        self.radioButton_aff.setGeometry(QtCore.QRect(160, 460, 112, 23))
        self.radioButton_aff.setObjectName("radioButton_aff")
        self.radioButton_con = QtWidgets.QRadioButton(Ui_Dialog)
        self.radioButton_con.setGeometry(QtCore.QRect(410, 460, 112, 23))
        self.radioButton_con.setObjectName("radioButton_con")
        self.radioButton_una = QtWidgets.QRadioButton(Ui_Dialog)
        self.radioButton_una.setGeometry(QtCore.QRect(720, 460, 112, 23))
        self.radioButton_una.setObjectName("radioButton_una")
        self.label_3 = QtWidgets.QLabel(Ui_Dialog)
        self.label_3.setGeometry(QtCore.QRect(30, 430, 181, 17))
        self.label_3.setObjectName("label_3")
        self.line_3 = QtWidgets.QFrame(Ui_Dialog)
        self.line_3.setGeometry(QtCore.QRect(20, 490, 971, 16))
        self.line_3.setFrameShape(QtWidgets.QFrame.HLine)
        self.line_3.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line_3.setObjectName("line_3")
        self.label_4 = QtWidgets.QLabel(Ui_Dialog)
        self.label_4.setGeometry(QtCore.QRect(30, 510, 211, 17))
        self.label_4.setObjectName("label_4")
        self.lineEdit = QtWidgets.QLineEdit(Ui_Dialog)
        self.lineEdit.setGeometry(QtCore.QRect(260, 510, 113, 25))
        self.lineEdit.setAlignment(QtCore.Qt.AlignRight | QtCore.Qt.AlignTrailing | QtCore.Qt.AlignVCenter)
        self.lineEdit.setObjectName("lineEdit")
        self.btngroup1 = QtWidgets.QButtonGroup()

        self.btngroup1.addButton(self.radioButton_aff)
        self.btngroup1.addButton(self.radioButton_con)
        self.btngroup1.addButton(self.radioButton_una)

        self.radioButton_aff.setChecked(True)

        # Aquí se conecta el botón de Ok con la funcionalidad que quieres.
        # En concreto, el método de actualizar que se define luego.
        self.buttonBox.accepted.connect(self.actualizar)
        self.retranslateUi(Ui_Dialog)
        QtCore.QMetaObject.connectSlotsByName(Ui_Dialog)

    def retranslateUi(self, Dialog):
        _translate = QtCore.QCoreApplication.translate
        Dialog.setWindowTitle(_translate("Dialog", "Dialog"))
        Dialog.setWindowTitle(_translate("Dialog", "Dialog"))
        self.checkBox_avg.setText(_translate("Dialog", "Average blurring"))
        self.label.setText(_translate("Dialog", "Select the techniques for data distillation."))
        self.checkBox_biBlu.setText(_translate("Dialog", "Bilateral blurring"))
        self.checkBox_crop.setText(_translate("Dialog", "Crop"))
        self.checkBox_blu.setText(_translate("Dialog", "Change to lab colour"))
        self.checkBox_blur2.setText(_translate("Dialog", "Blurring"))
        self.checkBox_hsv.setText(_translate("Dialog", "Change to hsv colour"))
        self.checkBox_his.setText(_translate("Dialog", "Equalize histogram"))
        self.checkBox_gam.setText(_translate("Dialog", "Gamma correction"))
        self.checkBox_ver.setText(_translate("Dialog", "Vertical flip"))
        self.checkBox_flip.setText(_translate("Dialog", "Horizontal flip"))
        self.checkBox_hvflip.setText(_translate("Dialog", "Vertical and horizontal flip"))
        self.checkBox_elas.setText(_translate("Dialog", "Elastic deformation"))
        self.checkBox_inv.setText(_translate("Dialog", "Invert"))
        self.checkBox_green.setText(_translate("Dialog", "Raise green channel"))
        self.checkBox_med.setText(_translate("Dialog", "Median blurring"))
        self.checkBox_none.setText(_translate("Dialog", "None"))
        self.checkBox_blue.setText(_translate("Dialog", "Raise blue channel"))
        self.checkBox_add.setText(_translate("Dialog", "Add gaussian noise"))
        self.checkBox_sat.setText(_translate("Dialog", "Raise saturation"))
        self.checkBox_r90.setText(_translate("Dialog", " Rotate 90º"))
        self.checkBox_val.setText(_translate("Dialog", "Raise value"))
        self.checkBox_resi.setText(_translate("Dialog", "Resize"))
        self.checkBox_r10.setText(_translate("Dialog", "Rotate 10º"))
        self.checkBox_red.setText(_translate("Dialog", "Raise red"))
        self.checkBox_drop.setText(_translate("Dialog", "Dropout"))
        self.checkBox_gau.setText(_translate("Dialog", "Gaussian blurring"))
        self.checkBox_hue.setText(_translate("Dialog", "Raise hue"))
        self.checkBox_r180.setText(_translate("Dialog", "Rotate 180º"))
        self.checkBox_trans.setText(_translate("Dialog", "Translation"))
        self.checkBox_r270.setText(_translate("Dialog", "Rotate 270º"))
        self.checkBox_shift.setText(_translate("Dialog", "Shift channel"))
        self.checkBox_salt.setText(_translate("Dialog", "Salt and pepper"))
        self.checkBox_shear.setText(_translate("Dialog", "Shearing"))
        self.checkBox_shar.setText(_translate("Dialog", "Sharpen"))
        self.radioButton_con.setText(_translate("Dialog", "Consensus"))
        self.label_4.setText(_translate("Dialog", "Select the level of confidence:"))
        self.label_3.setText(_translate("Dialog", "Select the ensemble method."))
        self.radioButton_aff.setText(_translate("Dialog", "Affirmative"))
        self.lineEdit.setText(_translate("Dialog", "0.4"))
        self.radioButton_una.setText(_translate("Dialog", "Unanimous"))

    def actualizar(self):
        self.genera = True
        #-------------------
        rbaff = self.radioButton_aff.isChecked()
        rbcon = self.radioButton_con.isChecked()
        rbuna = self.radioButton_una.isChecked()
        #-------------------------
        le1 = self.lineEdit.text()
        # ahora miramos el resultado de los checkbox
        ch1 = self.checkBox_avg.isChecked()
        ch2 = self.checkBox_biBlu.isChecked()
        ch3 = self.checkBox_blu.isChecked()
        ch4 = self.checkBox_hsv.isChecked()
        ch5 = self.checkBox_blur2.isChecked()
        ch6 = self.checkBox_crop.isChecked()
        ch7 = self.checkBox_drop.isChecked()
        ch8 = self.checkBox_elas.isChecked()
        ch9 = self.checkBox_his.isChecked()
        ch10 = self.checkBox_ver.isChecked()
        ch11 = self.checkBox_flip.isChecked()
        ch12 = self.checkBox_hvflip.isChecked()
        ch13 = self.checkBox_gam.isChecked()
        ch14 = self.checkBox_gau.isChecked()
        ch15 = self.checkBox_add.isChecked()
        ch16 = self.checkBox_inv.isChecked()
        ch17 = self.checkBox_med.isChecked()
        ch18 = self.checkBox_none.isChecked()
        ch19 = self.checkBox_blue.isChecked()
        ch20 = self.checkBox_green.isChecked()
        ch21 = self.checkBox_hue.isChecked()
        ch22 = self.checkBox_red.isChecked()
        ch23 = self.checkBox_sat.isChecked()
        ch24 = self.checkBox_val.isChecked()
        ch25 = self.checkBox_resi.isChecked()
        ch26 = self.checkBox_r10.isChecked()
        ch27 = self.checkBox_r90.isChecked()
        ch28 = self.checkBox_r180.isChecked()
        ch29 = self.checkBox_r270.isChecked()
        ch30 = self.checkBox_salt.isChecked()
        ch31 = self.checkBox_shar.isChecked()
        ch33 = self.checkBox_shift.isChecked()
        ch34 = self.checkBox_shear.isChecked()
        ch35 = self.checkBox_trans.isChecked()


        self.avg = ch1
        self.bila = ch2
        self.blur = ch3
        self.chanhsv = ch4
        self.chanlab = ch5
        self.crop = ch6
        self.drop = ch7
        self.elas = ch8
        self.histo = ch9
        self.vflip = ch10
        self.hflip = ch11
        self.hvflip = ch12
        self.gamma = ch13
        self.blurGa = ch14
        self.gaunoise = ch15
        self.invert = ch16
        self.median = ch17
        self.none = ch18
        self.raiseB = ch19
        self.raiseGreen = ch20
        self.raiseHue = ch21
        self.raisered = ch22
        self.raisesatu = ch23
        self.raiseval = ch24
        self.resize = ch25
        self.rot10 = ch26
        self.rot90 = ch27
        self.rot180 = ch28
        self.rot270 = ch29
        self.saltpe = ch30
        self.sharpen = ch31
        self.sift = ch33
        self.shear = ch34
        self.trans = ch35

        self.aff = rbaff
        self.con = rbcon
        self.una = rbuna

        self.conf = le1

        # Se cierra el dialogo
        self.dialog.close()


if __name__ == "__main__":
    import sys
    app = QtWidgets.QApplication(sys.argv)
    Dialog = QtWidgets.QDialog()
    ui = Ui_Dialog()
    ui.setupUi(Dialog)
    Dialog.show()
    sys.exit(app.exec_())



#!/usr/bin/python
# -*- coding: utf-8 -*-


try:
    from PyQt5.QtGui import *
    from PyQt5.QtCore import *
except ImportError:
    from PyQt4.QtGui import *
    from PyQt4.QtCore import *

from libs.utils import distance
import sys

DEFAULT_LINE_COLOR = QColor(0, 255, 0, 128)
DEFAULT_FILL_COLOR = QColor(255, 0, 0, 128)
DEFAULT_SELECT_LINE_COLOR = QColor(255, 255, 255)
DEFAULT_SELECT_FILL_COLOR = QColor(0, 128, 255, 155)
DEFAULT_VERTEX_FILL_COLOR = QColor(0, 255, 0, 255)
DEFAULT_HVERTEX_FILL_COLOR = QColor(255, 0, 0)
MIN_Y_LABEL = 10


class Shape(object):
    P_SQUARE, P_ROUND = range(2)

    MOVE_VERTEX, NEAR_VERTEX = range(2)

    # The following class variables influence the drawing
    # of _all_ shape objects.
    line_color = DEFAULT_LINE_COLOR
    fill_color = DEFAULT_FILL_COLOR
    select_line_color = DEFAULT_SELECT_LINE_COLOR
    select_fill_color = DEFAULT_SELECT_FILL_COLOR
    vertex_fill_color = DEFAULT_VERTEX_FILL_COLOR
    hvertex_fill_color = DEFAULT_HVERTEX_FILL_COLOR
    point_type = P_ROUND
    point_size = 8
    scale = 1.0

    def __init__(self, label=None, line_color=None, difficult=False, paintLabel=False):
        self.label = label
        self.points = []
        self.fill = False
        self.selected = False
        self.difficult = difficult
        self.paintLabel = paintLabel

        self._highlightIndex = None
        self._highlightMode = self.NEAR_VERTEX
        self._highlightSettings = {
            self.NEAR_VERTEX: (4, self.P_ROUND),
            self.MOVE_VERTEX: (1.5, self.P_SQUARE),
        }

        self._closed = False

        if line_color is not None:
            # Override the class line_color attribute
            # with an object attribute. Currently this
            # is used for drawing the pending line a different color.
            self.line_color = line_color

    def close(self):
        self._closed = True

    def reachMaxPoints(self):
        if len(self.points) >= 4:
            return True
        return False

    def addPoint(self, point):
        if not self.reachMaxPoints():
            self.points.append(point)

    def popPoint(self):
        if self.points:
            return self.points.pop()
        return None

    def isClosed(self):
        return self._closed

    def setOpen(self):
        self._closed = False

    def paint(self, painter):
        if self.points:
            color = self.select_line_color if self.selected else self.line_color
            pen = QPen(color)
            # Try using integer sizes for smoother drawing(?)
            pen.setWidth(max(1, int(round(2.0 / self.scale))))
            painter.setPen(pen)

            line_path = QPainterPath()
            vrtx_path = QPainterPath()

            line_path.moveTo(self.points[0])
            # Uncommenting the following line will draw 2 paths
            # for the 1st vertex, and make it non-filled, which
            # may be desirable.
            #self.drawVertex(vrtx_path, 0)

            for i, p in enumerate(self.points):
                line_path.lineTo(p)
                self.drawVertex(vrtx_path, i)
            if self.isClosed():
                line_path.lineTo(self.points[0])

            painter.drawPath(line_path)
            painter.drawPath(vrtx_path)
            painter.fillPath(vrtx_path, self.vertex_fill_color)

            # Draw text at the top-left
            if self.paintLabel:
                min_x = sys.maxsize
                min_y = sys.maxsize
                for point in self.points:
                    min_x = min(min_x, point.x())
                    min_y = min(min_y, point.y())
                if min_x != sys.maxsize and min_y != sys.maxsize:
                    font = QFont()
                    font.setPointSize(8)
                    font.setBold(True)
                    painter.setFont(font)
                    if(self.label == None):
                        self.label = ""
                    if(min_y < MIN_Y_LABEL):
                        min_y += MIN_Y_LABEL
                    painter.drawText(min_x, min_y, self.label)

            if self.fill:
                color = self.select_fill_color if self.selected else self.fill_color
                painter.fillPath(line_path, color)

    def drawVertex(self, path, i):
        d = self.point_size / self.scale
        shape = self.point_type
        point = self.points[i]
        if i == self._highlightIndex:
            size, shape = self._highlightSettings[self._highlightMode]
            d *= size
        if self._highlightIndex is not None:
            self.vertex_fill_color = self.hvertex_fill_color
        else:
            self.vertex_fill_color = Shape.vertex_fill_color
        if shape == self.P_SQUARE:
            path.addRect(point.x() - d / 2, point.y() - d / 2, d, d)
        elif shape == self.P_ROUND:
            path.addEllipse(point, d / 2.0, d / 2.0)
        else:
            assert False, "unsupported vertex shape"

    def nearestVertex(self, point, epsilon):
        for i, p in enumerate(self.points):
            if distance(p - point) <= epsilon:
                return i
        return None

    def containsPoint(self, point):
        return self.makePath().contains(point)

    def makePath(self):
        path = QPainterPath(self.points[0])
        for p in self.points[1:]:
            path.lineTo(p)
        return path

    def boundingRect(self):
        return self.makePath().boundingRect()

    def moveBy(self, offset):
        self.points = [p + offset for p in self.points]

    def moveVertexBy(self, i, offset):
        self.points[i] = self.points[i] + offset

    def highlightVertex(self, i, action):
        self._highlightIndex = i
        self._highlightMode = action

    def highlightClear(self):
        self._highlightIndex = None

    def copy(self):
        shape = Shape("%s" % self.label)
        shape.points = [p for p in self.points]
        shape.fill = self.fill
        shape.selected = self.selected
        shape._closed = self._closed
        if self.line_color != Shape.line_color:
            shape.line_color = self.line_color
        if self.fill_color != Shape.fill_color:
            shape.fill_color = self.fill_color
        shape.difficult = self.difficult
        return shape

    def __len__(self):
        return len(self.points)

    def __getitem__(self, key):
        return self.points[key]

    def __setitem__(self, key, value):
        self.points[key] = value



#!/usr/bin/env python
# -*- coding: utf-8 -*-

from setuptools import setup, find_packages, Command
from sys import platform as _platform
from shutil import rmtree
import sys
import os

here = os.path.abspath(os.path.dirname(__file__))
NAME = 'labelStoma'
REQUIRES_PYTHON = '>=3.0.0'
REQUIRED_DEP = ['pyqt5', 'lxml','imutils==0.5.1','tqdm==4.31.0','opencv_python==4.1.2.30','XlsxWriter==1.2.6','six==1.11.0','numpy','Pillow==7.0.0','progressbar2==3.47.0','scikit_learn==0.22.1','pandas==0.23.4','xlwt','sip==5.0.0']
about = {}

with open(os.path.join(here, 'libs', '__init__.py')) as f:
    exec(f.read(), about)

readme = ""
#with open('README.md') as readme_file:
#    readme = readme_file.read()

with open('HISTORY.rst') as history_file:
    history = history_file.read()


# OS specific settings
SET_REQUIRES = []
if _platform == "linux" or _platform == "linux2":
   # linux
   print('linux')
elif _platform == "darwin":
   # MAC OS X
   SET_REQUIRES.append('py2app')

required_packages = find_packages()
required_packages.append('labelStoma')
required_packages.append('notebooks')
required_packages.append('predict')
required_packages.append('fichs')
APP = [NAME + '.py']
OPTIONS = {
    'argv_emulation': True,
    'iconfile': 'resources/icons/app.icns'
}

class UploadCommand(Command):
    """Support setup.py upload."""

    description=readme + '\n\n' + history,

    user_options = []

    @staticmethod
    def status(s):
        """Prints things in bold."""
        print('\033[1m{0}\033[0m'.format(s))

    def initialize_options(self):
        pass

    def finalize_options(self):
        pass

    def run(self):
        try:
            self.status('Removing previous builds…')
            rmtree(os.path.join(here, 'dist'))
        except OSError:
            self.status('Fail to remove previous builds..')
            pass

        self.status('Building Source and Wheel (universal) distribution…')
        os.system(
            '{0} setup.py sdist bdist_wheel --universal'.format(sys.executable))

        self.status('Uploading the package to PyPI via Twine…')
        os.system('twine upload dist/*')

        self.status('Pushing git tags…')
        os.system('git tag -d v{0}'.format(about['__version__']))
        os.system('git tag v{0}'.format(about['__version__']))
        # os.system('git push --tags')

        sys.exit()


setup(
    app=APP,
    name=NAME,
    version="0.2.5",
    description="labelStoma is a graphical tool for using and creating detection models",
    long_description="labelStoma is a graphical tool for using and creating detection models",
    author="Angela Casado",
    author_email='angela.casado@unirioja.es',
    url='https://github.com/ancasag/labelStoma',
    python_requires=REQUIRES_PYTHON,
    package_dir={'labelStoma': '.'},
    packages=required_packages,
    entry_points={
        'console_scripts': [
            'labelStoma=labelStoma.labelStoma:main'
        ]
    },
    include_package_data=True,
    install_requires=REQUIRED_DEP,
    license="MIT license",
    zip_safe=False,
    keywords='labelStoma detection deeplearning',
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Natural Language :: English',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
    ],
    package_data={'data/predefined_classes.txt': ['data/predefined_classes.txt'],'notebooks': ['notebooks/*.ipynb'],'fichs/vocEstomas.names': ['fichs/vocEstomas.names'],'fichs/yolov3Estomas.cfg': ['fichs/yolov3Estomas.cfg'],'resources/strings/strings.properties':['resources/strings/strings.properties'],'resources/strings/strings-zh-CN.properties':['resources/strings/strings-zh-CN.properties'],'resources/strings/strings-zh-TW.properties':['resources/strings/strings-zh-TW.properties']},
    options={'py2app': OPTIONS},
    setup_requires=SET_REQUIRES,
    # $ setup.py publish support.
    cmdclass={
        'upload': UploadCommand,
    }
)



import abc
from abc import ABC

#abstract class
class IPredictor(ABC):
    #constructor
    def __init__(self, weightPath):
        self.pathPesos = weightPath

    @abc.abstractmethod
    def predict(self,imgPath):
        pass

#heritage
class DarknetYoloPred(IPredictor):
    
    def __init__(self,weightPath,fichNames, fichCfg):
        IPredictor.__init__(self, weightPath)
        self.fichNames = fichNames
        self.fichCfg = fichCfg

    def predict(self, imgPath, output, conf):
        import predict.detect
        predict.detect.mainDataset(imgPath, output, conf, self.pathPesos, self.fichNames, self.fichCfg)


class MXnetYoloPred(IPredictor):

    def __init__(self,weightPath,classes):
        IPredictor.__init__(self, weightPath)
        self.classes=classes

    def predict(self, imgPath, output, conf):
        import predict.predict_batch
        predict.predict_batch.mainDataset(imgPath, output, conf,'yolo3_darknet53_custom', self.pathPesos, self.classes)

class MXnetSSD512Pred(IPredictor):

    def __init__(self,weightPath,classes):
        IPredictor.__init__(self, weightPath)
        self.classes=classes

    def predict(self, imgPath, output, conf):
        import predict.predict_batch
        predict.predict_batch.mainDataset(imgPath, output, conf,'ssd_512_resnet50_v1_custom',self.pathPesos, self.classes)

class MXnetFasterRCNNPred(IPredictor):
    
    def __init__(self,weightPath,classes):
        IPredictor.__init__(self, weightPath)
        self.classes=classes

    def predict(self, imgPath, output, conf):
        import predict.predict_batch
        predict.predict_batch.mainDataset(imgPath, output, conf,'faster_rcnn_resnet50_v1b_custom', self.pathPesos, self.classes)

class RetinaNetResnet50Pred(IPredictor):
    
    def __init__(self,weightPath,classes):
        IPredictor.__init__(self, weightPath)
        self.classes=classes

    def predict(self, imgPath, output, conf):
        import predict.predict_batch_retinanet
        predict.predict_batch_retinanet.mainDataset(imgPath, output, conf,'resnet50_v1', self.pathPesos, self.classes)

class MaskRCNNPred(IPredictor):
    
    def __init__(self,weightPath,classes):
        IPredictor.__init__(self, weightPath)
        self.classes=classes

    def predict(self, imgPath, output, conf):
        import predict.predict_batch_rcnn
        predict.predict_batch_rcnn.mainDataset(imgPath, output, conf, self.pathPesos, self.classes)


class Efficient(IPredictor):

    def __init__(self, weightPath, classes):
        IPredictor.__init__(self, weightPath)
        self.classes = classes

    def predict(self, imgPath, output, conf):
        import predict.predict_batch_efficient
        predict.predict_batch_efficient.mainDataset(imgPath, output, conf, self.pathPesos, self.classes)

class FSAF(IPredictor):

    def __init__(self, weightPath, classes):
        IPredictor.__init__(self, weightPath)
        self.classes = classes

    def predict(self, imgPath, output, conf):
        import predict.predict_batch_FSAF
        predict.predict_batch_FSAF.mainDataset(imgPath, output, conf, self.pathPesos, self.classes)

class FCOS(IPredictor):

    def __init__(self, weightPath, classes):
        IPredictor.__init__(self, weightPath)
        self.classes = classes

    def predict(self, imgPath, output, conf):
        import predict.predict_batch_FCOS
        predict.predict_batch_FCOS.mainDataset(imgPath, output, conf, self.pathPesos, self.classes)


#!/usr/bin/env python
# -*- coding: utf-8 -*-
import sys
try:
    from PyQt5.QtGui import *
    from PyQt5.QtCore import *
    from PyQt5.QtWidgets import *
except ImportError:
    # needed for py3+qt4
    # Ref:
    # http://pyqt.sourceforge.net/Docs/PyQt4/incompatible_apis.html
    # http://stackoverflow.com/questions/21217399/pyqt4-qtcore-qvariant-object-instead-of-a-string
    if sys.version_info.major >= 3:
        import sip
        sip.setapi('QVariant', 2)
    from PyQt4.QtGui import *
    from PyQt4.QtCore import *

# PyQt5: TypeError: unhashable type: 'QListWidgetItem'


class HashableQListWidgetItem(QListWidgetItem):

    def __init__(self, *args):
        super(HashableQListWidgetItem, self).__init__(*args)

    def __hash__(self):
        return hash(id(self))
